..
    Copyright (C) 2020 CESNET.

    OARepo Micro API is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Authors
=======

- Miroslav Bauer @ CESNET
